@@ -1,111 +1,106 @@
 package Workflow::Action::InputField;
 
-# $Id: InputField.pm 454 2009-01-12 10:04:02Z jonasbn $
+# $Id: InputField.pm,v 1.8 2004/05/14 05:13:52 cwinters Exp $
 
-use warnings;
 use strict;
 use base qw( Class::Accessor );
-use Log::Log4perl qw( get_logger );
+use Log::Log4perl       qw( get_logger );
 use Workflow::Exception qw( configuration_error );
-use English qw( -no_match_vars );
 
-$Workflow::Action::InputField::VERSION = '1.09';
+$Workflow::Action::InputField::VERSION  = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
-my @FIELDS
-    = qw( name label description type requirement source_class source_list );
-__PACKAGE__->mk_accessors(@FIELDS);
+my @FIELDS = qw( name label description type requirement source_class source_list );
+__PACKAGE__->mk_accessors( @FIELDS );
 
 my %INCLUDED = ();
 
 sub new {
     my ( $class, $params ) = @_;
     my $log = get_logger();
-    $log->debug("Instantiating new field '$params->{name}'")
-        if $params->{name};
+    $log->debug( "Instantiating new field '$params->{name}'" );
 
-    my $self = bless {}, $class;
+    my $self = bless( {}, $class );
 
     # Set all our parameters
-    foreach my $field (@FIELDS) {
-        next unless ( $params->{$field} );
-        $self->$field( $params->{$field} );
+    foreach my $field ( @FIELDS ) {
+        next unless ( $params->{ $field } );
+        $self->$field( $params->{ $field } );
     }
 
     # ...ensure our name is defined
     unless ( $self->name ) {
-        my $id_string = '['
-            . join(
-            '] [', map {"$_: $params->{$_}"}
-                sort keys %{$params}
-            ) . ']';
+        my $id_string = '[' .
+                        join( '] [', map { "$_: $params->{$_}" }
+                                         sort keys %{ $params } ) .
+                        ']';
         configuration_error "Field found without name: $id_string";
     }
 
     my $name = $self->name;
     unless ( $self->label ) {
-        $self->label($name);
+        $self->label( $name );
     }
-    my $requirement = ( defined $params->{is_required}
-            && $params->{is_required} eq 'yes' ) ? 'required' : 'optional';
-    $self->requirement($requirement);
+    my $requirement = ( defined $params->{is_required} && $params->{is_required} eq 'yes' )
+                        ? 'required' : 'optional';
+    $self->requirement( $requirement );
 
     # ...ensure a class associated with the input source exists
     if ( my $source_class = $self->source_class ) {
-        $log->debug("Possible values for '$name' from '$source_class'");
-        unless ( $INCLUDED{$source_class} ) {
+        $log->debug( "Possible values for '$name' from '$source_class'" );
+        unless ( $INCLUDED{ $source_class } ) {
             eval "require $source_class";
-            if ($EVAL_ERROR) {
+            if ( $@ ) {
                 configuration_error "Failed to include source class ",
-                    "'$source_class' used in field '$name'";
+                                    "'$source_class' used in field '$name'";
             }
-            $INCLUDED{$source_class}++;
+            $INCLUDED{ $source_class }++;
         }
-        $params->{values} = [ $source_class->get_possible_values($self) ];
-    } elsif ( $self->source_list ) {
-        $log->debug("Possible values for '$name' specified in config");
-        $params->{values} = [ split /\s*,\s*/, $self->source_list ];
+        $params->{values} = [ $source_class->get_possible_values( $self ) ];
+    }
+    elsif ( $self->source_list ) {
+        $log->debug( "Possible values for '$name' specified in config" );
+        $params->{values} = [ split( /\s*,\s*/, $self->source_list ) ];
     }
 
     my $values = $params->{values} || $params->{possible_values};
-    if ($values) {
-        my @add_values = ( ref $values eq 'ARRAY' ) ? @{$values} : ($values);
+    if ( $values ) {
+        my @add_values = ( ref $values eq 'ARRAY' ) ? @{ $values } : ( $values );
         $log->debug( "Values to use as source for field '$name': ",
-            join ', ', @add_values );
-        $self->add_possible_values(@add_values);
+                     join( ', ', @add_values ) );
+        $self->add_possible_values( @add_values );
     }
 
     # Assign the default field type, subclasses may override...
-    $self->type('basic');
+    $self->type( 'basic' );
 
-    $self->init($params);
+    $self->init( $params );
     return $self;
 }
 
-sub init {return}
+sub init { return }
 
 sub is_required {
-    my ($self) = @_;
+    my ( $self ) = @_;
     return ( $self->requirement eq 'required' ) ? 'yes' : 'no';
 }
 
 sub is_optional {
-    my ($self) = @_;
+    my ( $self ) = @_;
     return ( $self->requirement eq 'optional' ) ? 'yes' : 'no';
 }
 
 sub get_possible_values {
-    my ($self) = @_;
+    my ( $self ) = @_;
     $self->{_enumerated} ||= [];
     return @{ $self->{_enumerated} };
 }
 
 sub add_possible_values {
     my ( $self, @values ) = @_;
-    foreach my $value (@values) {
-        my $this_value =
-            ( ref $value eq 'HASH' )
-            ? $value
-            : { label => $value, value => $value };
+    foreach my $value ( @values ) {
+        my $this_value = ( ref $value eq 'HASH' )
+                           ? $value
+                           : { label => $value, value => $value };
         push @{ $self->{_enumerated} }, $this_value;
     }
     return @{ $self->{_enumerated} };
@@ -119,10 +114,6 @@ __END__
 
 Workflow::Action::InputField - Metadata about information required by an Action
 
-=head1 VERSION
-
-This documentation describes version 1.09 of this package
-
 =head1 SYNOPSIS
 
  # Declare the fields needed by your action in the configuration...
@@ -174,36 +165,32 @@ For instance, in the above declaration there are three fields,
 
 =head2 Public Methods
 
-=head3 new( \%params )
+B<new( \%params )>
 
 Typical constructor; will throw exception if 'name' is not defined or
 if the property 'source_class' is defined but the class it specifies
 is not available.
 
-=head3 is_required()
+B<is_required()>
 
 Returns 'yes' if field is required, 'no' if optional.
 
-=head3 is_optional()
+B<is_optional()>
 
 Returns 'yes' if field is optional, 'no' if required.
 
-=head3 get_possible_values()
+B<get_possible_values()>
 
 Returns list of possible values for this field. Each possible value is
 represented by a hashref with the keys 'label' and 'value' which makes
 it easy to create dropdown lists in templates and the like.
 
-=head3 add_possible_values( @values )
+B<add_possible_values( @values )>
 
 Adds possible values to be used for this field. Each item in
 C<@values> may be a simple scalar or a hashref with the keys 'label'
 and 'value'.
 
-=head3 init
-
-Init is a I<dummy> and just returns no special actions are taken
-
 =head2 Properties
 
 B<name> (required)
@@ -249,15 +236,11 @@ L<Workflow::Action>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2007 Chris Winters. All rights reserved.
+Copyright (c) 2003-2004 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
-
-Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
-
-=cut
+Chris Winters E<lt>chris@cwinters.comE<gt>
