@@ -1,12 +1,12 @@
 package Workflow::Base;
 
-# $Id: Base.pm 285 2007-06-18 19:57:58Z jonasbn $
+# $Id: Base.pm,v 1.5 2004/03/08 04:56:09 cwinters Exp $
 
 use strict;
 use base qw( Class::Accessor );
 use Log::Log4perl;
 
-$Workflow::Base::VERSION  = '1.08';
+$Workflow::Base::VERSION  = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 sub new {
     my ( $class, @params ) = @_;
@@ -28,7 +28,7 @@ sub init { return }
 
 sub param {
     my ( $self, $name, $value ) = @_;
-    unless ( defined $name ) {
+    unless ( $name ) {
         return { %{ $self->{PARAMS} } };
     }
 
@@ -41,7 +41,7 @@ sub param {
         return { %{ $self->{PARAMS} } };
     }
 
-    unless ( defined $value ) {
+    unless ( $value ) {
         if ( exists $self->{PARAMS}{ $name } ) {
             return $self->{PARAMS}{ $name };
         }
@@ -50,35 +50,6 @@ sub param {
     return $self->{PARAMS}{ $name } = $value;
 }
 
-sub delete_param {
-    my ( $self, $name ) = @_;
-    unless ( defined $name ) {
-        ## this is an error - perhaps an exception is too radical
-        return undef;
-    }
-
-    # Allow multiple parameters to be deleted at once...
-
-    if ( ref $name eq 'ARRAY' ) {
-        my %list = ();
-        foreach my $param_name ( @{ $name } ) {
-	    next if (not exists $self->{PARAMS}{ $param_name });
-	    $list{$param_name} = $self->{PARAMS}{ $param_name }; 
-            delete $self->{PARAMS}{ $param_name }
-        }
-        return { %list };
-    }
-
-    if ( exists $self->{PARAMS}{ $name } ) {
-        my $value = $self->{PARAMS}{ $name };
-	delete $self->{PARAMS}{ $name };
-        return $value;
-    }
-
-    ## this is an error - perhaps an exception is too radical
-    return undef;
-}
-
 sub clear_params {
     my ( $self ) = @_;
     $self->{PARAMS} = {};
@@ -112,7 +83,7 @@ Provide a constructor and some other useful methods for subclasses.
 
 =head2 Class Methods
 
-=head3 new( @params )
+B<new( @params )>
 
 Just create a new object (blessed hashref) and pass along C<@params>
 to the C<init()> method, which subclasses can override to initialize
@@ -122,12 +93,12 @@ Returns: new object
 
 =head2 Object Methods
 
-=head3 init( @params )
+B<init( @params )>
 
 Subclasses may implement to do initialization. The C<@params> are
 whatever is passed into C<new()>. Nothing need be returned.
 
-=head3 param( [ $name, $value ] )
+B<param( [ $name, $value ] )>
 
 Associate arbitrary parameters with this object.
 
@@ -159,34 +130,11 @@ overwriting any existing value, and return the new value.
 
  $object->param( foo => 'blurney' );
 
-=head3 delete_param( [ $name ] )
-
-Delete parameters from this object.
-
-If C<$name> given and it is an array reference, then delete all
-parameters from this object. All deleted parameters will be returned
-as a hash reference together with their values.
-
- my $deleted = $object->delete_param(['foo','baz']);
- foreach my $key (keys %{$deleted})
- {
-   print $key."::=".$deleted->{$key}."\n";
- }
-
-If C<$name> given and it is not an array reference, delete the
-parameter and return the value of the parameter.
-
- my $value = $object->delete_param( 'foo' );
- print "Value of 'foo' was '$value'\n";
-
-If C<$name> is not defined or C<$name> does not exists the
-undef is returned.
-
-=head3 clear_params()
+B<clear_params()>
 
 Clears out all parameters associated with this object.
 
-=head3 normalize_array( \@array | $item )
+B<normalize_array( \@array | $item )>
 
 If given C<\@array> return it dereferenced; if given C<$item>, return
 it in a list. If given neither return an empty list.
