@@ -1,6 +1,6 @@
 package Workflow::Factory;
 
-# $Id: Factory.pm,v 1.15 2004/10/17 15:22:44 cwinters Exp $
+# $Id: Factory.pm,v 1.16 2005/11/30 03:10:52 cwinters Exp $
 
 use strict;
 use base qw( Workflow::Base );
@@ -8,7 +8,7 @@ use DateTime;
 use Log::Log4perl       qw( get_logger );
 use Workflow::Exception qw( configuration_error workflow_error );
 
-$Workflow::Factory::VERSION  = sprintf("%d.%02d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
+$Workflow::Factory::VERSION  = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 my ( %INSTANCES );
@@ -123,6 +123,7 @@ sub add_config_from_file {
     $self->_add_workflow_config(
         Workflow::Config->parse_all_files( 'workflow', $params{workflow} )
     );
+    return;
 }
 
 sub add_config {
@@ -134,6 +135,7 @@ sub add_config {
     $self->_add_persister_config( _flatten( $params{persister} ) );
     $self->_add_action_config( _flatten( $params{action} ) );
     $self->_add_workflow_config( _flatten( $params{workflow} ) );
+    return;
 }
 
 sub _check_config_keys {
@@ -667,6 +669,9 @@ objects should already be read in. A good order is: 'validator',
 references to C<add_config()> using the right type and the behavior
 should be exactly the same.
 
+Returns: nothing; if we run into a problem parsing one of the files or
+creating the objects it requires we throw a L<Workflow::Exception>.
+
 B<add_config( %config_hashrefs )>
 
 Similar to C<add_config_from_file()> -- the keys may be 'action',
@@ -680,6 +685,10 @@ specified by a user) or using a custom configuration format and for
 some reason do not want to use the built-in mechanism in
 L<Workflow::Config> to read it for you.
 
+Returns: nothing; if we encounter an error trying to create the
+objects referenced in a configuration we throw a
+L<Workflow::Exception>.
+
 =head2 Internal Methods
 
 B<save_workflow( $workflow )>
