@@ -1,6 +1,6 @@
 package Workflow::Persister::SPOPS;
 
-# $Id: SPOPS.pm 361 2008-04-05 13:23:31Z jonasbn $
+# $Id: SPOPS.pm,v 1.6 2004/03/08 04:56:09 cwinters Exp $
 
 use strict;
 use base qw( Workflow::Persister );
@@ -8,7 +8,7 @@ use DateTime;
 use Log::Log4perl       qw( get_logger );
 use Workflow::Exception qw( configuration_error persist_error );
 
-$Workflow::Persister::SPOPS::VERSION = '1.07';
+$Workflow::Persister::SPOPS::VERSION  = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( workflow_class history_class );
 __PACKAGE__->mk_accessors( @FIELDS );
@@ -35,7 +35,7 @@ sub create_workflow {
     my $wf_persist = $self->workflow_class->new({
         state       => $wf->state,
         type        => $wf->type,
-        last_update => DateTime->now(time_zone => $wf->time_zone()),
+        last_update => DateTime->now,
     });
     eval { $wf_persist->save };
     if ( $@ ) {
@@ -120,7 +120,6 @@ sub fetch_history {
             user         => $_->user,
 # NOTE: SPOPS class must return this as a DateTime object...
             date         => $_->history_date,
-	    time_zone    => $_->time_zone,
         });
         $hist->set_saved();
         push @histories, $hist;
@@ -166,66 +165,6 @@ use the L<SPOPS::Tool::DateConvert> to translate the 'history_date'
 field into a L<DateTime> object. We assume when we fetch the history
 object that this has already been done.
 
-=head2 METHODS
-
-=head3 init ( \%params)
-
-This method initializes the SPOPS persistance entity.
-
-It requires that a workflow_class and a history_class are specified. If not the
-case L<Workflow::Exception>s are thrown.
-
-=head3 create_workflow
-
-Serializes a workflow into the persistance entity configured by our workflow.
-
-Takes a single parameter: a workflow object
-
-Returns a single value, a id for unique identification of out serialized
-workflow for possible deserialization.
-
-=head3 fetch_workflow
-
-Deserializes a workflow from the persistance entity configured by our workflow.
-
-Takes a single parameter: the unique id assigned to our workflow upon
-serialization (see L</create_workflow>).
-
-Returns a hashref consisting of two keys:
-
-=over
-
-=item * state, the workflows current state
-
-=item * last_update, date indicating last update
-
-=back
-
-=head3 update_workflow
-
-Updates a serialized workflow in the persistance entity configured by our
-workflow.
-
-Takes a single parameter: a workflow object
-
-Returns: Nothing
-
-=head3 create_history
-
-Serializes history records associated with a workflow object
-
-Takes two parameters: a workflow object and an array of workflow history objects
-
-Returns: provided array of workflow history objects upon success
-
-=head3 fetch_history
-
-Deserializes history records associated with a workflow object
-
-Takes a single parameter: a workflow object
-
-Returns an array of workflow history objects upon success
-
 =head1 SEE ALSO
 
 L<Workflow::Persister>
@@ -236,15 +175,11 @@ L<SPOPS::Tool::DateConvert>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2007 Chris Winters. All rights reserved.
+Copyright (c) 2003-2004 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
-
-Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
-
-=cut
+Chris Winters E<lt>chris@cwinters.comE<gt>
